==> haskell-doctest-exitcode-stdio-0.0.0.1-63-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-exitcode-stdio
version:              0.0.0.1
visibility:           public
id:                   doctest-exitcode-stdio-0.0.0.1-800VSeleEH5CjnqYqOQyro
key:                  doctest-exitcode-stdio-0.0.0.1-800VSeleEH5CjnqYqOQyro
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  c57f4f63b0c16e9331cbe340afd4e3e9
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0.0.1-800VSeleEH5CjnqYqOQyro
depends:
    QuickCheck-2.15.0.1-4mIWiyi0MCz4O9NEuBQDps base-4.18.2.1
    doctest-lib-0.1.1.1-B4NEu7hRxm7ApFh0YX7J4I transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-exitcode-stdio-0.0.0.1-64-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-exitcode-stdio.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 doctest-exitcode-stdio
version:              0.0.0.1
visibility:           public
id:                   doctest-exitcode-stdio-0.0.0.1-KOkW5mlKz0Q6J3Fexh8R08
key:                  doctest-exitcode-stdio-0.0.0.1-KOkW5mlKz0Q6J3Fexh8R08
license:              BSD-3-Clause
maintainer:           Henning Thielemann <haskell@henning-thielemann.de>
author:               Henning Thielemann <haskell@henning-thielemann.de>
homepage:             https://hub.darcs.net/thielema/doctest-exitcode-stdio/
synopsis:             Run doctest'\''s in a Cabal.Test.exitcode-stdio environment
description:
    Run doctest'\''s in a Cabal.Test.exitcode-stdio environment.
    For use with the @doctest-extract@ utility.
    Normally, you should not need to import a module from this package,
    only generated code will do this.

category:             Testing
abi:                  136353f1abf32a6ac1b9fb99576625bc
exposed:              True
exposed-modules:      Test.DocTest.Driver
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/doctest-exitcode-stdio-0.0.0.1

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-exitcode-stdio
hs-libraries:         HSdoctest-exitcode-stdio-0.0.0.1-KOkW5mlKz0Q6J3Fexh8R08
depends:
    QuickCheck-2.15.0.1-LaRIQHiwv8U7w9VIoXbmQQ base-4.18.2.1
    doctest-lib-0.1.1.1-B4NEu7hRxm7ApFh0YX7J4I transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-exitcode-stdio/html/doctest-exitcode-stdio.haddock

haddock-html:         /usr/share/doc/haskell-doctest-exitcode-stdio/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
